@@ -1,7 +1,7 @@
-from typing import Any
-
 from notionary.blocks.schemas import Block, BlockChildrenResponse, BlockCreatePayload
 from notionary.http.client import NotionHttpClient
+from notionary.shared.typings import JsonDict
+from notionary.utils.decorators import time_execution_async
 from notionary.utils.pagination import paginate_notion_api
 
 
@@ -16,6 +16,7 @@ class NotionBlockHttpClient(NotionHttpClient):
         self.logger.debug("Deleting block: %s", block_id)
         await self.delete(f"blocks/{block_id}")
 
+    @time_execution_async()
     async def get_block_tree(self, parent_block_id: str) -> list[Block]:
         blocks_at_this_level = await self.get_all_block_children(parent_block_id)
 
@@ -26,6 +27,7 @@ class NotionBlockHttpClient(NotionHttpClient):
 
         return blocks_at_this_level
 
+    @time_execution_async()
     async def get_all_block_children(self, parent_block_id: str) -> list[Block]:
         self.logger.debug("Retrieving all children for block: %s", parent_block_id)
 
@@ -73,11 +75,11 @@ class NotionBlockHttpClient(NotionHttpClient):
             batches.append(batch)
         return batches
 
-    def _serialize_blocks(self, blocks: list[BlockCreatePayload]) -> list[dict[str, Any]]:
+    def _serialize_blocks(self, blocks: list[BlockCreatePayload]) -> list[JsonDict]:
         return [block.model_dump(exclude_none=True) for block in blocks]
 
     async def _send_append_request(
-        self, block_id: str, children: list[dict[str, Any]], after_block_id: str | None = None
+        self, block_id: str, children: list[JsonDict], after_block_id: str | None = None
     ) -> BlockChildrenResponse:
         payload = {"children": children}
         if after_block_id:
