@@ -1,9 +1,11 @@
+from .data_source import DataSourceNameIdResolver
 from .database import DatabaseNameIdResolver
 from .page import PageNameIdResolver
 from .person import PersonNameIdResolver
 from .port import NameIdResolver
 
 __all__ = [
+    "DataSourceNameIdResolver",
     "DatabaseNameIdResolver",
     "NameIdResolver",
     "PageNameIdResolver",
