@@ -4,7 +4,7 @@ from typing import Annotated, Literal
 
 from pydantic import BaseModel, ConfigDict, Field
 
-from notionary.blocks.enums import BlockColor, BlockType, CodeLanguage, FileType
+from notionary.blocks.enums import BlockColor, BlockType, CodingLanguage, FileType
 from notionary.blocks.rich_text.models import RichText
 from notionary.shared.models.icon import Icon
 from notionary.shared.models.parent import Parent
@@ -129,19 +129,27 @@ class CreateBreadcrumbBlock(BaseModel):
 # ============================================================================
 
 
-class BulletedListItemData(BaseModel):
+class BaseBulletedListItemData(BaseModel):
     rich_text: list[RichText]
     color: BlockColor = BlockColor.DEFAULT
 
 
+class BulletedListItemData(BaseBulletedListItemData):
+    children: list[Block] | None = None
+
+
 class BulletedListItemBlock(BaseBlock):
     type: Literal[BlockType.BULLETED_LIST_ITEM] = BlockType.BULLETED_LIST_ITEM
     bulleted_list_item: BulletedListItemData
 
 
+class CreateBulletedListItemData(BaseBulletedListItemData):
+    children: list[BlockCreatePayload] | None = None
+
+
 class CreateBulletedListItemBlock(BaseModel):
     type: Literal[BlockType.BULLETED_LIST_ITEM] = BlockType.BULLETED_LIST_ITEM
-    bulleted_list_item: BulletedListItemData
+    bulleted_list_item: CreateBulletedListItemData
 
 
 # ============================================================================
@@ -219,7 +227,7 @@ class CreateChildDatabaseBlock(BaseModel):
 class CodeData(BaseModel):
     caption: list[RichText] = Field(default_factory=list)
     rich_text: list[RichText]
-    language: CodeLanguage = CodeLanguage.PLAIN_TEXT
+    language: CodingLanguage = CodingLanguage.PLAIN_TEXT
 
     model_config = ConfigDict(arbitrary_types_allowed=True)
 
@@ -433,19 +441,27 @@ class CreateImageBlock(BaseModel):
 # ============================================================================
 
 
-class NumberedListItemData(BaseModel):
+class BaseNumberedListItemData(BaseModel):
     rich_text: list[RichText]
     color: BlockColor = BlockColor.DEFAULT
 
 
+class NumberedListItemData(BaseNumberedListItemData):
+    children: list[Block] | None = None
+
+
 class NumberedListItemBlock(BaseBlock):
     type: Literal[BlockType.NUMBERED_LIST_ITEM] = BlockType.NUMBERED_LIST_ITEM
     numbered_list_item: NumberedListItemData
 
 
+class CreateNumberedListItemData(BaseNumberedListItemData):
+    children: list[BlockCreatePayload] | None = None
+
+
 class CreateNumberedListItemBlock(BaseModel):
     type: Literal[BlockType.NUMBERED_LIST_ITEM] = BlockType.NUMBERED_LIST_ITEM
-    numbered_list_item: NumberedListItemData
+    numbered_list_item: CreateNumberedListItemData
 
 
 # ============================================================================
@@ -453,19 +469,27 @@ class CreateNumberedListItemBlock(BaseModel):
 # ============================================================================
 
 
-class ParagraphData(BaseModel):
+class BaseParagraphData(BaseModel):
     rich_text: list[RichText]
     color: BlockColor = BlockColor.DEFAULT
 
 
+class ParagraphData(BaseParagraphData):
+    children: list[Block] | None = None
+
+
 class ParagraphBlock(BaseBlock):
     type: Literal[BlockType.PARAGRAPH] = BlockType.PARAGRAPH
     paragraph: ParagraphData
 
 
+class CreateParagraphData(BaseParagraphData):
+    children: list[BlockCreatePayload] | None = None
+
+
 class CreateParagraphBlock(BaseModel):
     type: Literal[BlockType.PARAGRAPH] = BlockType.PARAGRAPH
-    paragraph: ParagraphData
+    paragraph: CreateParagraphData
 
 
 # ============================================================================
@@ -588,20 +612,28 @@ class CreateTableOfContentsBlock(BaseModel):
 # ============================================================================
 
 
-class ToDoData(BaseModel):
+class BaseToDoData(BaseModel):
     rich_text: list[RichText]
     checked: bool = False
     color: BlockColor = BlockColor.DEFAULT
 
 
+class ToDoData(BaseToDoData):
+    children: list[Block] | None = None
+
+
 class ToDoBlock(BaseBlock):
     type: Literal[BlockType.TO_DO] = BlockType.TO_DO
     to_do: ToDoData
 
 
+class CreateToDoData(BaseToDoData):
+    children: list[BlockCreatePayload] | None = None
+
+
 class CreateToDoBlock(BaseModel):
     type: Literal[BlockType.TO_DO] = BlockType.TO_DO
-    to_do: ToDoData
+    to_do: CreateToDoData
 
 
 # ============================================================================
