@@ -1,7 +1,7 @@
 from collections.abc import Callable
 from typing import Self
 
-from notionary.data_source.properties.models import DataSourceProperty
+from notionary.data_source.properties.schemas import DataSourceProperty
 from notionary.data_source.query.schema import (
     ArrayOperator,
     BooleanOperator,
@@ -24,7 +24,7 @@ from notionary.data_source.query.schema import (
     TimestampSort,
     TimestampType,
 )
-from notionary.data_source.query.validator import OperatorValidator
+from notionary.data_source.query.validator import QueryValidator
 from notionary.exceptions.data_source.properties import DataSourcePropertyNotFound
 from notionary.utils.date import parse_date
 
@@ -33,11 +33,11 @@ class DataSourceQueryBuilder:
     def __init__(
         self,
         properties: dict[str, DataSourceProperty],
-        operator_validator: OperatorValidator | None = None,
+        query_validator: QueryValidator | None = None,
         date_parser: Callable[[str], str] = parse_date,
     ) -> None:
         self._properties = properties
-        self._operator_validator = operator_validator or OperatorValidator()
+        self._query_validator = query_validator or QueryValidator()
         self._date_parser = date_parser
 
         self._filters: list[InternalFilterCondition] = []
@@ -45,6 +45,8 @@ class DataSourceQueryBuilder:
         self._current_property: str | None = None
         self._negate_next = False
         self._or_group: list[FilterCondition] | None = None
+        self._page_size: int | None = None
+        self._total_results_limit: int | None = None
 
     def where(self, property_name: str) -> Self:
         self._finalize_current_or_group()
@@ -164,27 +166,53 @@ class DataSourceQueryBuilder:
         self._sorts.append(sort)
         return self
 
-    def order_by_ascending(self, property_name: str) -> Self:
+    def order_by_property_name_ascending(self, property_name: str) -> Self:
         return self.order_by(property_name, SortDirection.ASCENDING)
 
-    def order_by_descending(self, property_name: str) -> Self:
+    def order_by_property_name_descending(self, property_name: str) -> Self:
         return self.order_by(property_name, SortDirection.DESCENDING)
 
-    def order_by_created_time(self, direction: SortDirection = SortDirection.DESCENDING) -> Self:
+    def order_by_created_time_ascending(self) -> Self:
+        return self._order_by_created_time(SortDirection.ASCENDING)
+
+    def order_by_created_time_descending(self) -> Self:
+        return self._order_by_created_time(SortDirection.DESCENDING)
+
+    def _order_by_created_time(self, direction: SortDirection = SortDirection.DESCENDING) -> Self:
         sort = TimestampSort(timestamp=TimestampType.CREATED_TIME, direction=direction)
         self._sorts.append(sort)
         return self
 
-    def order_by_last_edited_time(self, direction: SortDirection = SortDirection.DESCENDING) -> Self:
+    def order_by_last_edited_time_ascending(self) -> Self:
+        return self._order_by_last_edited_time(SortDirection.ASCENDING)
+
+    def order_by_last_edited_time_descending(self) -> Self:
+        return self._order_by_last_edited_time(SortDirection.DESCENDING)
+
+    def _order_by_last_edited_time(self, direction: SortDirection = SortDirection.DESCENDING) -> Self:
         sort = TimestampSort(timestamp=TimestampType.LAST_EDITED_TIME, direction=direction)
         self._sorts.append(sort)
         return self
 
+    def total_results_limit(self, total_result_limit: int) -> Self:
+        if total_result_limit < 1:
+            raise ValueError("Limit must be at least 1")
+        self._total_results_limit = total_result_limit
+        return self
+
+    def page_size(self, page_size: int) -> Self:
+        if page_size < 1:
+            raise ValueError("Page size must be at least 1")
+        self._page_size = page_size
+        return self
+
     def build(self) -> DataSourceQueryParams:
         self._finalize_current_or_group()
         notion_filter = self._create_notion_filter_if_needed()
         sorts = self._create_sorts_if_needed()
-        return DataSourceQueryParams(filter=notion_filter, sorts=sorts)
+        return DataSourceQueryParams(
+            filter=notion_filter, sorts=sorts, page_size=self._page_size, total_results_limit=self._total_results_limit
+        )
 
     def _select_property_without_negation(self, property_name: str) -> None:
         self._current_property = property_name
@@ -273,7 +301,7 @@ class DataSourceQueryBuilder:
 
         property_obj = self._properties.get(self._current_property)
         if property_obj:
-            self._operator_validator.validate_operator_for_property(self._current_property, property_obj, operator)
+            self._query_validator.validate_operator_for_property(self._current_property, property_obj, operator)
         return self
 
     def _ensure_property_is_selected(self) -> None:
