@@ -1,7 +1,7 @@
 from pydantic import BaseModel
 
 from notionary.blocks.rich_text.models import RichText
-from notionary.data_source.properties.models import DiscriminatedDataSourceProperty
+from notionary.data_source.properties.schemas import DiscriminatedDataSourceProperty
 from notionary.page.schemas import NotionPageDto
 from notionary.shared.entity.schemas import EntityResponseDto, NotionEntityUpdateDto
 from notionary.shared.models.parent import Parent
