@@ -4,7 +4,7 @@ from typing import override
 
 from notionary.blocks.schemas import BookmarkData, CreateBookmarkBlock
 from notionary.page.content.parser.parsers.base import BlockParsingContext, LineParser
-from notionary.page.content.syntax.service import SyntaxRegistry
+from notionary.page.content.syntax import SyntaxRegistry
 
 
 class BookmarkParser(LineParser):
