@@ -9,7 +9,7 @@ from notionary.blocks.schemas import (
     FileType,
 )
 from notionary.page.content.parser.parsers.base import BlockParsingContext, LineParser
-from notionary.page.content.syntax.service import SyntaxRegistry
+from notionary.page.content.syntax import SyntaxRegistry
 
 
 class PdfParser(LineParser):
